Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/doitsujin/dxvk.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--src/util/config/config.cpp9
1 files changed, 6 insertions, 3 deletions
diff --git a/src/util/config/config.cpp b/src/util/config/config.cpp
index 6cd72ae8..ba8356d1 100644
--- a/src/util/config/config.cpp
+++ b/src/util/config/config.cpp
@@ -54,13 +54,16 @@ namespace dxvk {
/* Far Cry 3: Assumes clear(0.5) on an UNORM *
* format to result in 128 on AMD and 127 on *
* Nvidia. We assume that the Vulkan drivers *
* match the clear behaviour of D3D11. */
{ R"(\\(farcry3|fc3_blooddragon)_d3d11\.exe$)", {{
{ "dxgi.hideNvidiaGpu", "False" },
+ { "dxgi.hideIntelGpu", "True" },
}} },
- /* Far Cry 4: Same as Far Cry 3 */
- { R"(\\FarCry4\.exe$)", {{
+ /* Far Cry 4 and Primal: Same as Far Cry 3 */
+ { R"(\\(FarCry4|FCPrimal)\.exe$)", {{
{ "dxgi.hideNvidiaGpu", "False" },
+ { "dxgi.hideIntelGpu", "True" },
}} },
/* Frostpunk: Renders one frame with D3D9 *
* after creating the DXGI swap chain */
@@ -54,13 +54,16 @@ namespace dxvk {
* format to result in 128 on AMD and 127 on *
* Nvidia. We assume that the Vulkan drivers *
- * match the clear behaviour of D3D11. */
+ * match the clear behaviour of D3D11. *
+ * Intel needs to match the AMD result */
{ R"(\\(farcry3|fc3_blooddragon)_d3d11\.exe$)", {{
{ "dxgi.hideNvidiaGpu", "False" },